==> wifieye_0.4.0.orig.tar.gz: wifieye-0.4.0/src/scan.py <==
#!/usr/bin/env python
# coding=UTF-8
#
# Copyright (C) 2010 Stefanos Harhalakis
#
# This file is part of wifieye.
#
# wifieye is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# wifieye is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with wifieye.  If not, see <http://www.gnu.org/licenses/>.
#
# $Id: scan.py 2250 2010-02-13 13:46:35Z v13 $

import pythonwifi.flags
from pythonwifi.iwlibs import Wireless
import pickle, subprocess, time

iface="wlan0"

w=Wireless(iface)

netwasdown=False

try:
    r=w.scan()
except IOError, ex:
    if ex.errno==100:	# Network is down
	netwasdown=True
    else:
	# Generic error
	r={}

if netwasdown:
    subprocess.call(["/sbin/ifconfig", iface, "up"])
    # Allow some time for interface to become ready
    time.sleep(0.2)
    try:
	r=w.scan()
    except Exception, ex:
	print ex
    subprocess.call(["/sbin/ifconfig", iface, "down"])

dt={}

for i in r:
    d={
	'bssid':    i.bssid,
	'essid':    i.essid,
	'mode':	    i.mode,
	'quality':  {
	    'quality':	i.quality.quality,
	    'noise':	i.quality.getNoiselevel(),
	    'signal':	i.quality.getSignallevel(),
	    },
	'freq':	    {
	    'm':    i.frequency.m,	# Frequency in MHz
	    'e':    i.frequency.e,
	    },
	'rates':    i.rate,
	}
    dt[i.bssid]=d
#    print d

print pickle.dumps(dt)

# vim: set ts=8 sts=4 sw=4 noet formatoptions=r ai nocindent:

==> wifieye_1.0.orig.tar.gz: wifieye-1.0/src/scan.py <==
#!/usr/bin/env python
# coding=UTF-8
#
# Copyright (C) 2010 Stefanos Harhalakis
#
# This file is part of wifieye.
#
# wifieye is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# wifieye is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with wifieye.  If not, see <http://www.gnu.org/licenses/>.
#
# $Id: scan.py 2472 2010-04-28 19:39:06Z v13 $

__version__ = "$Id: scan.py 2472 2010-04-28 19:39:06Z v13 $"

import pythonwifi.flags
from pythonwifi.iwlibs import Wireless
import pickle, subprocess, time

iface="wlan0"

w=Wireless(iface)

netwasdown=False

# From /usr/include/wireless.h

enc_capa=[
    ('WPA',	0x00000001),	# IW_ENC_CAPA_WPA
    ('WPA2',	0x00000002),	# IW_ENC_CAPA_WPA2
    ('TKIP',	0x00000004),	# IW_ENC_CAPA_CIPHER_TKIP
    ('CCMP',	0x00000008),	# IW_ENC_CAPA_CIPHER_CCMP
    ]

auth_wpa=[
    ('DISABLED',    0x00000001),    # IW_AUTH_WPA_VERSION_DISABLED
    ('WPA',	    0x00000002),    # IW_AUTH_WPA_VERSION_WPA
    ('WPA2',	    0x00000004),    # IW_AUTH_WPA_VERSION_WPA2
    ]

auth_cipher=[
    ('NONE',	    0x00000001),    # IW_AUTH_CIPHER_NONE
    ('WEP40',	    0x00000002),    # IW_AUTH_CIPHER_WEP40
    ('TKIP',	    0x00000004),    # IW_AUTH_CIPHER_TKIP
    ('CCMP',	    0x00000008),    # IW_AUTH_CIPHER_CCMP
    ('WEP104',	    0x00000010),    # IW_AUTH_CIPHER_WEP104
    ]

auth_key_mgmt=[
    ('8021X',	    1),		    # IW_AUTH_KEY_MGMT_802_1X
    ('PSK',	    2),		    # IW_AUTH_KEY_MGMT_PSK
    ]

try:
    r=w.scan()
except IOError, ex:
    if ex.errno==100:	# Network is down
	netwasdown=True
    else:
	# Generic error
	r={}

if netwasdown:
    subprocess.call(["/sbin/ifconfig", iface, "up"])
    # Allow some time for interface to become ready
    time.sleep(0.2)
    try:
	r=w.scan()
    except Exception, ex:
	print ex
    subprocess.call(["/sbin/ifconfig", iface, "down"])

dt={}

for i in r:
    d={
	'bssid':    i.bssid,
	'essid':    i.essid,
	'mode':	    i.mode,
	'quality':  {
	    'quality':	i.quality.quality,
	    'noise':	i.quality.getNoiselevel(),
	    'signal':	i.quality.getSignallevel(),
	    },
	'freq':	    {
	    'm':    i.frequency.m * \
		    (10 ** i.frequency.e) / (10 ** 6), # Frequency in MHz
	    'e':    i.frequency.e,
	    },
	'rates':    i.rate,
	}
    dt[i.bssid]=d
#    print d

print pickle.dumps(dt)

# vim: set ts=8 sts=4 sw=4 noet formatoptions=r ai nocindent:
